@@ -258,9 +258,9 @@ class MongoDbPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpena
 
         value = PropertyReflector.get_properties(value)
 
-        if value.get('_id'):
-            value['id'] = value['_id']
-            value.pop('_id', None)
+        if value.get('id'):
+            value['_id'] = value.get('id') or value.get('_id')
+            value.pop('id', None)
         return value
 
     def is_open(self) -> bool:
@@ -352,6 +352,7 @@ class MongoDbPersistence(IReferenceable, IUnreferenceable, IConfigurable, IOpena
             self._db = None
             self._client = None
 
+            self.__opened = False
             self._logger.debug(correlation_id, "Disconnected from mongodb database " + str(self._database_name))
         except Exception as ex:
             raise ConnectionException(None, 'DISCONNECT_FAILED', 'Disconnect from mongodb failed: ' + str(ex)) \
